@@ -47,11 +47,10 @@ class FreqDict(models.Model):
                 continue
             cat = SyntacticCategory.objects.get(pk=int(lemmas[key]['CategoryNum']))
             w = Word.objects.create(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq']))
-
             for spell in lemmas[key]['Spellings']:
                 ss.append(Spelling(Label=spell,Word=w))
             for trans in lemmas[key]['Transcriptions']:
-                ts.append(Transcription(Transcription=trans,Word=w)
+                ts.append(Transcription(Transcription=trans,Word=w))
         Spelling.objects.bulk_create(ss)
         Transcription.objects.bulk_create(ts)
 
